| Title: | slurm tooling |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | Devin Pastoor [aut, cre], Jenna Elwing [aut], Matthew Smith [aut], Jacob Dumbleton [aut] |
| Maintainer: | Devin Pastoor <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.4 |
| Built: | 2026-05-17 08:52:37 UTC |
| Source: | https://github.com/a2-ai/slurmtools |
Cancels a running job
cancel_slurm_job(job_id, auto_confirm = FALSE)cancel_slurm_job(job_id, auto_confirm = FALSE)
job_id |
job id to cancel |
auto_confirm |
does not prompt user before cancelling job |
## Not run: cancel_job(243) ## End(Not run)## Not run: cancel_job(243) ## End(Not run)
Gets the jobs run on slurm as a tibble
get_slurm_jobs(user = NULL)get_slurm_jobs(user = NULL)
user |
optional user name to filter jobs only submitted by user |
a tibble containing the jobs submitted to slurm
## Not run: get_slurm_jobs() ## End(Not run)## Not run: get_slurm_jobs() ## End(Not run)
Gets the available slurm partitions the user can use.
get_slurm_partitions(cache = TRUE)get_slurm_partitions(cache = TRUE)
cache |
optional argument to forgo caching |
vector of available partitions
## Not run: get_slurm_partitions ## End(Not run)## Not run: get_slurm_partitions ## End(Not run)
This package aims to ease the submission and monitoring of NONMEM jobs running on slurm.
submit_slurm_job: Submits a job to slurm
get_slurm_jobs: Gives a table of submitted jobs to slurm
that shows status and other information given with squeue
cancel_slurm_job: Cancels the specified job
get_slurm_partitions: Gives a vector of available
partitions a user can submit jobs to.
Maintainer: Devin Pastoor [email protected]
Authors:
Jenna Elwing [email protected]
Matthew Smith [email protected]
Jacob Dumbleton [email protected]
submit a nonmem model to slurm in parallel
submit_slurm_job( .mod, partition = get_slurm_partitions(), ncpu = 1, overwrite = FALSE, dry_run = FALSE, ..., slurm_job_template_path = getOption("slurmtools.slurm_job_template_path"), submission_root = getOption("slurmtools.submission_root"), bbi_config_path = getOption("slurmtools.bbi_config_path"), slurm_template_opts = list() )submit_slurm_job( .mod, partition = get_slurm_partitions(), ncpu = 1, overwrite = FALSE, dry_run = FALSE, ..., slurm_job_template_path = getOption("slurmtools.slurm_job_template_path"), submission_root = getOption("slurmtools.submission_root"), bbi_config_path = getOption("slurmtools.bbi_config_path"), slurm_template_opts = list() )
.mod |
a path to a model or a bbi nonmem model object |
partition |
name of the partition to submit the model |
ncpu |
number of cpus to run the model against |
overwrite |
whether to overwrite existing model results |
dry_run |
return the command that would have been invoked, without invoking |
... |
arguments to pass to processx::run |
slurm_job_template_path |
path to slurm job template |
submission_root |
directory to track job submission scripts and output |
bbi_config_path |
path to bbi.yaml file for bbi configuration |
slurm_template_opts |
choose slurm template |
Updates the logging level for functions. Default is set to WARN
toggle_logger(quiet = FALSE)toggle_logger(quiet = FALSE)
quiet |
suppresses messaging about log level. |
## Not run: Sys.setenv("RPFY_VERBOSE" = "DEBUG") toggle_logger() ## End(Not run)## Not run: Sys.setenv("RPFY_VERBOSE" = "DEBUG") toggle_logger() ## End(Not run)